@@ -86,7 +86,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55500
 #  endif
 #endif
 
@@ -175,6 +175,12 @@
 #else
 #  define PLASMA_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if PLASMA_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define PLASMA_DEPRECATED_VERSION_5_85(text) PLASMA_DECL_DEPRECATED_TEXT(text)
+#else
+#  define PLASMA_DEPRECATED_VERSION_5_85(text)
+#endif
 #define PLASMA_DEPRECATED_VERSION_5(minor, text)      PLASMA_DEPRECATED_VERSION_5_##minor(text)
 #define PLASMA_DEPRECATED_VERSION(major, minor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define PLASMA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -240,7 +246,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -250,7 +256,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55500
 #  endif
 #endif
 
@@ -329,6 +335,12 @@
 #else
 #  define PLASMA_DEPRECATED_VERSION_5_83(text)
 #endif
+
+#if PLASMA_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define PLASMA_DEPRECATED_VERSION_5_85(text) PLASMA_DECL_DEPRECATED_TEXT(text)
+#else
+#  define PLASMA_DEPRECATED_VERSION_5_85(text)
+#endif
 #define PLASMA_DEPRECATED_VERSION_5(minor, text)      PLASMA_DEPRECATED_VERSION_5_##minor(text)
 #define PLASMA_DEPRECATED_VERSION(major, minor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define PLASMA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PLASMA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
